Keen | Column Rendering Examples
Description: Column rendering datatables examples

# Customer Relationship Management

New Order

### Column Rendering Examples

Reports
Each column has an optional rendering control called columns.render which can be used to process the content of each cell before the data is used. See official documentation here.

### Column Rendering

Record ID | Company Email | Company Agent | Company Name | Status | Type | Actions
--- | --- | --- | --- | --- | --- | ---
1 | nsailor0@livejournal.com | Nixie Sailor | Gleichner, Ziemann and Gutkowski | 3 | 2 |
2 | egiraldez1@seattletimes.com | Emelita Giraldez | Rosenbaum-Reichel | 6 | 3 |
3 | uluckin2@state.gov | Ula Luckin | Kulas, Cassin and Batz | 1 | 2 |
4 | ecure3@trellian.com | Evangeline Cure | Pfannerstill-Treutel | 1 | 3 |
5 | tst4@msn.com | Tierney St. Louis | Dicki-Kling | 2 | 3 |
6 | greinhard5@instagram.com | Gerhard Reinhard | Gleason, Kub and Marquardt | 5 | 3 |
7 | eshelley6@pcworld.com | Englebert Shelley | Jenkins Inc | 2 | 3 |
8 | hkite7@epa.gov | Hazlett Kite | Streich LLC | 6 | 1 |
9 | fmorby8@surveymonkey.com | Freida Morby | Haley, Schamberger and Durgan | 2 | 1 |
10 | ohelian9@usatoday.com | Obed Helian | Labadie, Predovic and Hammes | 1 | 3 |
11 | samya@earthlink.net | Sibyl Amy | Treutel-Ratke | 4 | 2 |
12 | nfoldesb@lycos.com | Norri Foldes | Strosin, Nitzsche and Wisozk | 3 | 1 |
13 | morhtmannc@weibo.com | Myrna Orhtmann | Miller-Schiller | 3 | 1 |
14 | skneathd@bizjournals.com | Sioux Kneath | Rice, Cole and Spinka | 4 | 1 |
15 | cjacmare@google.pl | Christa Jacmar | Brakus-Hansen | 1 | 2 |
16 | sgoraccif@thetimes.co.uk | Shandee Goracci | Bergnaum, Thiel and Schuppe | 5 | 3 |
17 | jcolvieg@mit.edu | Jerrome Colvie | Kreiger, Glover and Connelly | 3 | 1 |
18 | mplenderleithh@globo.com | Michaelina Plenderleith | Legros-Gleichner | 1 | 2 |
19 | lluthwoodi@constantcontact.com | Lombard Luthwood | Haag LLC | 1 | 2 |
20 | lchevinj@mapy.cz | Leonora Chevin | Mann LLC | 2 | 3 |
21 | tseakesk@jigsy.com | Tannie Seakes | Blanda Group | 6 | 3 |
22 | ywetherelll@webnode.com | Yardley Wetherell | Gerlach-Schultz | 2 | 2 |
23 | bpeascodm@devhub.com | Bryn Peascod | Larkin and Sons | 6 | 1 |
24 | cjeromsonn@ning.com | Chrissie Jeromson | Brakus-McCullough | 2 | 1 |
25 | gclampo@vistaprint.com | Gusti Clamp | Stokes Group | 6 | 2 |
26 | ojobbinsp@w3.org | Otis Jobbins | Ruecker, Leffler and Abshire | 4 | 2 |
27 | lhaycoxq@samsung.com | Lonnie Haycox | Feest Group | 1 | 3 |
28 | hcastellir@nationalgeographic.com | Heddi Castelli | Kessler and Sons | 5 | 1 |
29 | todowgaines@princeton.edu | Tuck O'Dowgaine | Simonis, Rowe and Davis | 1 | 1 |
30 | vcoshamt@simplemachines.org | Vernon Cosham | Kreiger-Nicolas | 4 | 2 |
31 | bmaccrackenu@hostgator.com | Bryna MacCracken | Hyatt-Witting | 2 | 1 |
32 | farnallv@vistaprint.com | Freda Arnall | Dicki, Morar and Stiedemann | 3 | 3 |
33 | pkringew@usatoday.com | Pavel Kringe | Goldner-Lehner | 4 | 1 |
34 | fnazaretx@si.edu | Felix Nazaret | Waters, Quigley and Keeling | 5 | 3 |
35 | pallanbyy@discovery.com | Penrod Allanby | Rodriguez Group | 2 | 3 |
36 | hpassbyz@wikimedia.org | Hubey Passby | Lemke-Hermiston | 2 | 3 |
37 | mrotlauf10@naver.com | Magdaia Rotlauf | Hettinger, Medhurst and Heaney | 3 | 1 |
38 | alawrance11@un.org | Alfonse Lawrance | Schuppe-Harber | 1 | 3 |
39 | kchettoe12@zdnet.com | Kessiah Chettoe | Mraz LLC | 5 | 2 |
40 | nfairbanks13@geocities.com | Natka Fairbanks | Mueller-Greenholt | 3 | 3 |

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!